[kaffe] CVS kaffe (robilad): Resynced with GNU Classpath: fixed Javadocs all over

Kaffe CVS cvs-commits at kaffe.org
Wed Nov 24 19:49:24 PST 2004


PatchSet 5480 
Date: 2004/11/25 03:44:49
Author: robilad
Branch: HEAD
Tag: (none) 
Log:
Resynced with GNU Classpath: fixed Javadocs all over

Members: 
	ChangeLog:1.3026->1.3027 
	libraries/javalib/java/io/BufferedReader.java:1.16->1.17 
	libraries/javalib/java/io/FileInputStream.java:1.18->1.19 
	libraries/javalib/java/io/FileOutputStream.java:1.15->1.16 
	libraries/javalib/java/io/FileWriter.java:1.5->1.6 
	libraries/javalib/java/io/OutputStreamWriter.java:1.11->1.12 
	libraries/javalib/java/io/PipedInputStream.java:1.15->1.16 
	libraries/javalib/java/io/PipedOutputStream.java:1.6->1.7 
	libraries/javalib/java/io/PipedReader.java:1.9->1.10 
	libraries/javalib/java/io/PipedWriter.java:1.4->1.5 
	libraries/javalib/java/io/PrintStream.java:1.17->1.18 
	libraries/javalib/java/io/PushbackInputStream.java:1.7->1.8 
	libraries/javalib/java/io/RandomAccessFile.java:1.27->1.28 
	libraries/javalib/java/io/Reader.java:1.8->1.9 
	libraries/javalib/java/io/StreamTokenizer.java:1.24->1.25 
	libraries/javalib/java/io/StringReader.java:1.8->1.9 
	libraries/javalib/java/net/NetworkInterface.java:1.11->1.12 
	libraries/javalib/java/net/URLClassLoader.java:1.19->1.20 
	libraries/javalib/java/nio/ByteOrder.java:1.8->1.9 
	libraries/javalib/java/nio/channels/Channel.java:1.3->1.4 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.3026 kaffe/ChangeLog:1.3027
--- kaffe/ChangeLog:1.3026	Thu Nov 25 00:09:10 2004
+++ kaffe/ChangeLog	Thu Nov 25 03:44:49 2004
@@ -1,5 +1,51 @@
 2004-11-24  Dalibor Topic  <robilad at kaffe.org>
 
+	* libraries/javalib/java/io/BufferedReader.java,
+	libraries/javalib/java/io/FileInputStream.java,
+	libraries/javalib/java/io/FileOutputStream.java,
+	libraries/javalib/java/io/FileWriter.java,
+	libraries/javalib/java/io/OutputStreamWriter.java,
+	libraries/javalib/java/io/PipedInputStream.java,
+	libraries/javalib/java/io/PipedOutputStream.java,
+	libraries/javalib/java/io/PipedReader.java,
+	libraries/javalib/java/io/PipedWriter.java,
+	libraries/javalib/java/io/PrintStream.java,
+	libraries/javalib/java/io/PushbackInputStream.java,
+	libraries/javalib/java/io/RandomAccessFile.java,
+	libraries/javalib/java/io/Reader.java,
+	libraries/javalib/java/io/StreamTokenizer.java,
+	libraries/javalib/java/io/StringReader.java,
+	libraries/javalib/java/net/NetworkInterface.java,
+	libraries/javalib/java/net/URLClassLoader.java,
+	libraries/javalib/java/nio/ByteOrder.java,
+	libraries/javalib/java/nio/channels/Channel.java:
+	Resynced with GNU Classpath.
+
+	2004-11-16  Michael Koch  <konqueror at gmx.de>
+
+        * java/io/BufferedReader.java,
+        java/io/FileInputStream.java,
+        java/io/FileOutputStream.java,
+        java/io/FileWriter.java,
+        java/io/OutputStreamWriter.java,
+        java/io/PipedInputStream.java,
+        java/io/PipedOutputStream.java,
+        java/io/PipedReader.java,
+        java/io/PipedWriter.java,
+        java/io/PrintStream.java,
+        java/io/PushbackInputStream.java,
+        java/io/RandomAccessFile.java,
+        java/io/Reader.java,
+        java/io/StreamTokenizer.java,
+        java/io/StringReader.java,
+        java/net/NetworkInterface.java,
+        java/net/URLClassLoader.java,
+        java/nio/ByteOrder.java,
+        java/nio/channels/Channel.java:
+        Fixed javadocs all over.
+
+2004-11-24  Dalibor Topic  <robilad at kaffe.org>
+
 	* libraries/javalib/java/awt/color/ICC_ColorSpace.java,
 	libraries/javalib/java/awt/color/ICC_Profile.java,
 	libraries/javalib/java/awt/color/ICC_ProfileGray.java,
Index: kaffe/libraries/javalib/java/io/BufferedReader.java
diff -u kaffe/libraries/javalib/java/io/BufferedReader.java:1.16 kaffe/libraries/javalib/java/io/BufferedReader.java:1.17
--- kaffe/libraries/javalib/java/io/BufferedReader.java:1.16	Tue May 18 12:33:48 2004
+++ kaffe/libraries/javalib/java/io/BufferedReader.java	Thu Nov 25 03:44:53 2004
@@ -508,7 +508,7 @@
    * <code>skip</code> method on the underlying stream to skip the 
    * remaining chars.
    *
-   * @param numChars The requested number of chars to skip
+   * @param count The requested number of chars to skip
    *
    * @return The actual number of chars skipped.
    *
Index: kaffe/libraries/javalib/java/io/FileInputStream.java
diff -u kaffe/libraries/javalib/java/io/FileInputStream.java:1.18 kaffe/libraries/javalib/java/io/FileInputStream.java:1.19
--- kaffe/libraries/javalib/java/io/FileInputStream.java:1.18	Mon Oct  4 14:46:23 2004
+++ kaffe/libraries/javalib/java/io/FileInputStream.java	Thu Nov 25 03:44:53 2004
@@ -122,7 +122,7 @@
    * An exception is 
    * thrown if reading is not allowed.
    *
-   * @param fd The <code>FileDescriptor</code> object this stream 
+   * @param fdObj The <code>FileDescriptor</code> object this stream 
    * should read from
    *
    * @exception SecurityException If read access to the file is not allowed
Index: kaffe/libraries/javalib/java/io/FileOutputStream.java
diff -u kaffe/libraries/javalib/java/io/FileOutputStream.java:1.15 kaffe/libraries/javalib/java/io/FileOutputStream.java:1.16
--- kaffe/libraries/javalib/java/io/FileOutputStream.java:1.15	Mon Oct  4 14:46:23 2004
+++ kaffe/libraries/javalib/java/io/FileOutputStream.java	Thu Nov 25 03:44:53 2004
@@ -72,7 +72,7 @@
    * one exists) with the name of the file to be opened.  An exception is
    * thrown if writing is not allowed. 
    *
-   * @param name The name of the file this stream should write to
+   * @param path The name of the file this stream should write to
    * @param append <code>true</code> to append bytes to the end of the file,
    * or <code>false</code> to write bytes to the beginning
    *
@@ -95,7 +95,7 @@
    * one exists) with the name of the file to be opened.  An exception is
    * thrown if writing is not allowed. 
    *
-   * @param name The name of the file this stream should write to
+   * @param path The name of the file this stream should write to
    *
    * @exception SecurityException If write access to the file is not allowed
    * @exception FileNotFoundException If a non-security error occurs
@@ -176,7 +176,7 @@
    * one exists) with the specified <code>FileDescriptor</code> as an argument.
    * An exception is thrown if writing is not allowed. 
    *
-   * @param file The <code>FileDescriptor</code> this stream should write to
+   * @param fdObj The <code>FileDescriptor</code> this stream should write to
    *
    * @exception SecurityException If write access to the file is not allowed
    */
Index: kaffe/libraries/javalib/java/io/FileWriter.java
diff -u kaffe/libraries/javalib/java/io/FileWriter.java:1.5 kaffe/libraries/javalib/java/io/FileWriter.java:1.6
--- kaffe/libraries/javalib/java/io/FileWriter.java:1.5	Sat Aug 30 14:18:31 2003
+++ kaffe/libraries/javalib/java/io/FileWriter.java	Thu Nov 25 03:44:53 2004
@@ -1,5 +1,5 @@
 /* FileWriter.java -- Convenience class for writing to files.
-   Copyright (C) 1998, 1999, 2001, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2001, 2003, 2004  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -49,96 +49,89 @@
   * <code>OutputStreamWriter</code> to write to it.
   *
   * @author Aaron M. Renn (arenn at urbanophile.com)
-  * @author Tom Tromey <tromey at cygnus.com>
+  * @author Tom Tromey (tromey at cygnus.com)
   */
 public class FileWriter extends OutputStreamWriter
 {
-
-  /*
-   * Constructors
-   */
-   
   /**
-    * This method initializes a new <code>FileWriter</code> object to write
-    * to the specified <code>File</code> object.
-    *
-    * @param file The <code>File</code> object to write to.
-    *
-    * @param SecurityException If writing to this file is forbidden by the
-    *                          <code>SecurityManager</code>.
-    * @param IOException If any other error occurs
-    */
+   * This method initializes a new <code>FileWriter</code> object to write
+   * to the specified <code>File</code> object.
+   *
+   * @param file The <code>File</code> object to write to.
+   *
+   * @throws SecurityException If writing to this file is forbidden by the
+   * <code>SecurityManager</code>.
+   * @throws IOException If any other error occurs
+   */
   public FileWriter(File file) throws SecurityException, IOException
   {
     super(new FileOutputStream(file));
   }
 
   /**
-    * This method initializes a new <code>FileWriter</code> object to write
-    * to the specified <code>File</code> object.
-    *
-    * @param file The <code>File</code> object to write to.
-    * @param append <code>true</code> to start adding data at the end of the
-    *               file, <code>false</code> otherwise.
-    *
-    * @param SecurityException If writing to this file is forbidden by the
-    *                          <code>SecurityManager</code>.
-    * @param IOException If any other error occurs
-    */
+   * This method initializes a new <code>FileWriter</code> object to write
+   * to the specified <code>File</code> object.
+   *
+   * @param file The <code>File</code> object to write to.
+   * @param append <code>true</code> to start adding data at the end of the
+   * file, <code>false</code> otherwise.
+   *
+   * @throws SecurityException If writing to this file is forbidden by the
+   * <code>SecurityManager</code>.
+   * @throws IOException If any other error occurs
+   */
   public FileWriter(File file, boolean append) throws IOException
   {
     super(new FileOutputStream(file, append));
   }
 
   /**
-    * This method initializes a new <code>FileWriter</code> object to write
-    * to the specified <code>FileDescriptor</code> object.
-    *
-    * @param fd The <code>FileDescriptor</code> object to write to
-    *
-    * @param SecurityException If writing to this file is forbidden by the
-    *                          <code>SecurityManager</code>.
-    */
+   * This method initializes a new <code>FileWriter</code> object to write
+   * to the specified <code>FileDescriptor</code> object.
+   *
+   * @param fd The <code>FileDescriptor</code> object to write to
+   *
+   * @throws SecurityException If writing to this file is forbidden by the
+   * <code>SecurityManager</code>.
+   */
   public FileWriter(FileDescriptor fd) throws SecurityException
   {
     super(new FileOutputStream(fd));
   }
 
   /**
-    * This method intializes a new <code>FileWriter</code> object to 
-    * write to the
-    * specified named file.
-    *
-    * @param name The name of the file to write to
-    *
-    * @param SecurityException If writing to this file is forbidden by the
-    *                          <code>SecurityManager</code>.
-    * @param IOException If any other error occurs
-    */
+   * This method intializes a new <code>FileWriter</code> object to 
+   * write to the
+   * specified named file.
+   *
+   * @param name The name of the file to write to
+   *
+   * @throws SecurityException If writing to this file is forbidden by the
+   * <code>SecurityManager</code>.
+   * @throws IOException If any other error occurs
+   */
   public FileWriter(String name) throws IOException
   {
     super(new FileOutputStream(name));
   }
 
   /**
-    * This method intializes a new <code>FileWriter</code> object to 
-    * write to the
-    * specified named file.  This form of the constructor allows the caller
-    * to determin whether data should be written starting at the beginning or
-    * the end of the file.
-    *
-    * @param name The name of the file to write to
-    * @param append <code>true</code> to start adding data at the end of the
-    *               file, <code>false</code> otherwise.
-    *
-    * @param SecurityException If writing to this file is forbidden by the
-    *                          <code>SecurityManager</code>.
-    * @param IOException If any other error occurs
-    */
+   * This method intializes a new <code>FileWriter</code> object to 
+   * write to the
+   * specified named file.  This form of the constructor allows the caller
+   * to determin whether data should be written starting at the beginning or
+   * the end of the file.
+   *
+   * @param name The name of the file to write to
+   * @param append <code>true</code> to start adding data at the end of the
+   * file, <code>false</code> otherwise.
+   *
+   * @throws SecurityException If writing to this file is forbidden by the
+   * <code>SecurityManager</code>.
+   * @throws IOException If any other error occurs
+   */
   public FileWriter(String name, boolean append) throws IOException
   {
     super(new FileOutputStream(name, append));
   }
-
-} // class FileWriter
-
+}
Index: kaffe/libraries/javalib/java/io/OutputStreamWriter.java
diff -u kaffe/libraries/javalib/java/io/OutputStreamWriter.java:1.11 kaffe/libraries/javalib/java/io/OutputStreamWriter.java:1.12
--- kaffe/libraries/javalib/java/io/OutputStreamWriter.java:1.11	Tue May 18 03:35:07 2004
+++ kaffe/libraries/javalib/java/io/OutputStreamWriter.java	Thu Nov 25 03:44:53 2004
@@ -199,7 +199,7 @@
   /**
    * This method writes a single character to the output stream.
    *
-   * @param c The char to write, passed as an int.
+   * @param ch The char to write, passed as an int.
    *
    * @exception IOException If an error occurs
    */
Index: kaffe/libraries/javalib/java/io/PipedReader.java
diff -u kaffe/libraries/javalib/java/io/PipedReader.java:1.9 kaffe/libraries/javalib/java/io/PipedReader.java:1.10
--- kaffe/libraries/javalib/java/io/PipedReader.java:1.9	Tue May 18 03:35:08 2004
+++ kaffe/libraries/javalib/java/io/PipedReader.java	Thu Nov 25 03:44:54 2004
@@ -123,7 +123,7 @@
     * This stream is then ready for reading.  If this stream is already
     * connected or has been previously closed, then an exception is thrown
     *
-    * @param src The <code>PipedWriter</code> to connect this stream to
+    * @param source The <code>PipedWriter</code> to connect this stream to
     *
     * @exception IOException If this PipedReader or <code>source</code> 
     *                        has been connected already.
@@ -218,11 +218,7 @@
     * because the end of the stream was reached.  If the stream is already
     * closed, a -1 will again be returned to indicate the end of the stream.
     * <p>
-    * This method will block if no chars are available to be read.
-    *
-    * @param buf The buffer into which chars will be stored
-    * @param offset The index into the buffer at which to start writing.
-    * @param len The maximum number of chars to read.
+    * This method will block if no char is available to be read.
     */
   public int read() throws IOException
   {
@@ -233,11 +229,7 @@
     // if this method is never called.
 
     int r = read(read_buf, 0, 1);
-
-    if (r == -1)
-      return -1;
-    else
-      return read_buf[0];
+    return r != -1 ? read_buf[0] : -1;
   }
   
   /**
Index: kaffe/libraries/javalib/java/io/PrintStream.java
diff -u kaffe/libraries/javalib/java/io/PrintStream.java:1.17 kaffe/libraries/javalib/java/io/PrintStream.java:1.18
--- kaffe/libraries/javalib/java/io/PrintStream.java:1.17	Thu Nov 11 02:41:57 2004
+++ kaffe/libraries/javalib/java/io/PrintStream.java	Thu Nov 25 03:44:54 2004
@@ -231,7 +231,7 @@
    * values are printed as "true" and <code>false</code> values are printed
    * as "false".
    *
-   * @param b The <code>boolean</code> value to print
+   * @param bool The <code>boolean</code> value to print
    */
   public void print (boolean bool)
   {
@@ -325,7 +325,7 @@
    * This method prints an array of characters to the stream.  The actual
    * value printed depends on the system default encoding.
    *
-   * @param s The array of characters to print.
+   * @param charArray The array of characters to print.
    */
   public void print (char[] charArray)
   {
@@ -349,7 +349,7 @@
    * <p>
    * This method prints a line termination sequence after printing the value.
    *
-   * @param b The <code>boolean</code> value to print
+   * @param bool The <code>boolean</code> value to print
    */
   public void println (boolean bool)
   {
@@ -454,7 +454,7 @@
    * <p>
    * This method prints a line termination sequence after printing the value.
    *
-   * @param s The array of characters to print.
+   * @param charArray The array of characters to print.
    */
   public void println (char[] charArray)
   {
@@ -466,7 +466,7 @@
    * enabled, printing a newline character will cause the stream to be
    * flushed after the character is written.
    * 
-   * @param b The byte to be written
+   * @param oneByte The byte to be written
    */
   public void write (int oneByte)
   {
Index: kaffe/libraries/javalib/java/io/PushbackInputStream.java
diff -u kaffe/libraries/javalib/java/io/PushbackInputStream.java:1.7 kaffe/libraries/javalib/java/io/PushbackInputStream.java:1.8
--- kaffe/libraries/javalib/java/io/PushbackInputStream.java:1.7	Tue May 18 03:35:08 2004
+++ kaffe/libraries/javalib/java/io/PushbackInputStream.java	Thu Nov 25 03:44:54 2004
@@ -302,7 +302,7 @@
    * <code>skip</code> method on the underlying <code>InputStream</code> to 
    * skip additional bytes if necessary.
    *
-   * @param numBytes The requested number of bytes to skip
+   * @param n The requested number of bytes to skip
    *
    * @return The actual number of bytes skipped.
    *
Index: kaffe/libraries/javalib/java/io/Reader.java
diff -u kaffe/libraries/javalib/java/io/Reader.java:1.8 kaffe/libraries/javalib/java/io/Reader.java:1.9
--- kaffe/libraries/javalib/java/io/Reader.java:1.8	Sun Nov  2 13:29:37 2003
+++ kaffe/libraries/javalib/java/io/Reader.java	Thu Nov 25 03:44:54 2004
@@ -103,7 +103,7 @@
    *
    * @param buf The array into which the chars read should be stored
    * @param offset The offset into the array to start storing chars
-   * @param len The requested number of chars to read
+   * @param count The requested number of chars to read
    *
    * @return The actual number of chars read, or -1 if end of stream.
    *
@@ -189,7 +189,7 @@
     * <code>reset()</code> method is called, then the mark is invalid and the 
     * stream object instance is not required to remember the mark.
     *
-    * @param readlimit The number of chars that can be read before the mark 
+    * @param readLimit The number of chars that can be read before the mark 
     *        becomes invalid
     *
     * @exception IOException If an error occurs such as mark not being 
@@ -243,7 +243,7 @@
     * override this method to provide a more efficient implementation where
     * one exists.
     *
-    * @param num_chars The requested number of chars to skip
+    * @param count The requested number of chars to skip
     *
     * @return The actual number of chars skipped.
     *
Index: kaffe/libraries/javalib/java/io/StreamTokenizer.java
diff -u kaffe/libraries/javalib/java/io/StreamTokenizer.java:1.24 kaffe/libraries/javalib/java/io/StreamTokenizer.java:1.25
--- kaffe/libraries/javalib/java/io/StreamTokenizer.java:1.24	Tue May 18 03:35:08 2004
+++ kaffe/libraries/javalib/java/io/StreamTokenizer.java	Thu Nov 25 03:44:54 2004
@@ -122,7 +122,7 @@
    * them.  For details on how this method operates by default, see
    * <code>StreamTokenizer(Reader)</code>.
    *
-   * @param in The <code>InputStream</code> to read from
+   * @param is The <code>InputStream</code> to read from
    *
    * @deprecated Since JDK 1.1.
    */
@@ -150,7 +150,7 @@
    * <li>C  and C++ (//) comments are not recognized</li>
    * </ul>
    *
-   * @param in The <code>Reader</code> to read chars from
+   * @param r The <code>Reader</code> to read chars from
    */
   public StreamTokenizer(Reader r)
   {
@@ -170,7 +170,7 @@
    * This method sets the comment attribute on the specified
    * character.  Other attributes for the character are cleared.
    *
-   * @param c The character to set the comment attribute for, passed as an int
+   * @param ch The character to set the comment attribute for, passed as an int
    */
   public void commentChar(int ch)
   {
@@ -517,7 +517,7 @@
    * quote, or comment) will be set on this character.  This character will
    * parse as its own token.
    *
-   * @param c The character to make ordinary, passed as an int
+   * @param ch The character to make ordinary, passed as an int
    */
   public void ordinaryChar(int ch)
   {
@@ -533,9 +533,9 @@
    * range parse as its own token.
    *
    * @param low The low end of the range of values to set the whitespace
-   *            attribute for
-   * @param high The high end of the range of values to set the whitespace
-   *            attribute for
+   * attribute for
+   * @param hi The high end of the range of values to set the whitespace
+   * attribute for
    */
   public void ordinaryChars(int low, int hi)
   {
@@ -575,7 +575,7 @@
    * This method sets the quote attribute on the specified character.
    * Other attributes for the character are cleared.
    *
-   * @param c The character to set the quote attribute for, passed as an int.
+   * @param ch The character to set the quote attribute for, passed as an int.
    */
   public void quoteChar(int ch)
   {
@@ -670,9 +670,9 @@
    * specified range, range terminators included.
    *
    * @param low The low end of the range of values to set the whitespace
-   *            attribute for
-   * @param high The high end of the range of values to set the whitespace
-   *             attribute for
+   * attribute for
+   * @param hi The high end of the range of values to set the whitespace
+   * attribute for
    */
   public void whitespaceChars(int low, int hi)
   {
@@ -692,9 +692,9 @@
    * specified range, range terminators included.
    *
    * @param low The low end of the range of values to set the alphabetic
-   *            attribute for
-   * @param high The high end of the range of values to set the alphabetic
-   *             attribute for
+   * attribute for
+   * @param hi The high end of the range of values to set the alphabetic
+   * attribute for
    */
   public void wordChars(int low, int hi)
   {
Index: kaffe/libraries/javalib/java/io/StringReader.java
diff -u kaffe/libraries/javalib/java/io/StringReader.java:1.8 kaffe/libraries/javalib/java/io/StringReader.java:1.9
--- kaffe/libraries/javalib/java/io/StringReader.java:1.8	Sat Aug 30 14:18:31 2003
+++ kaffe/libraries/javalib/java/io/StringReader.java	Thu Nov 25 03:44:54 2004
@@ -52,7 +52,7 @@
  * method rewinds the read pointer to the beginning of the <code>String</code>.
  *
  * @author Aaron M. Renn (arenn at urbanophile.com)
- * @author Warren Levy <warrenl at cygnus.com>
+ * @author Warren Levy (warrenl at cygnus.com)
  * @date October 19, 1998.  
  */
 public class StringReader extends Reader
@@ -74,7 +74,7 @@
    * passed in <code>String</code>.  This stream will read from the beginning 
    * to the end of the <code>String</code>.
    *
-   * @param s The <code>String</code> this stream will read from.
+   * @param buffer The <code>String</code> this stream will read from.
    */
   public StringReader(String buffer)
   {
@@ -185,7 +185,7 @@
     * buffer, then only enough chars are skipped to position the stream at
     * the end of the buffer.  The actual number of chars skipped is returned.
     *
-    * @param num_chars The requested number of chars to skip
+    * @param n The requested number of chars to skip
     *
     * @return The actual number of chars skipped.
     */
Index: kaffe/libraries/javalib/java/net/NetworkInterface.java
diff -u kaffe/libraries/javalib/java/net/NetworkInterface.java:1.11 kaffe/libraries/javalib/java/net/NetworkInterface.java:1.12
--- kaffe/libraries/javalib/java/net/NetworkInterface.java:1.11	Sun Oct 24 00:47:57 2004
+++ kaffe/libraries/javalib/java/net/NetworkInterface.java	Thu Nov 25 03:44:54 2004
@@ -1,5 +1,5 @@
 /* NetworkInterface.java --
-   Copyright (C) 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -90,14 +90,14 @@
   }
 
   /**
-   *  Returns all available addresses of the network interface
+   * Returns all available addresses of the network interface
    *
-   *  If a @see SecurityManager is available all addresses are checked
-   *  with @see SecurityManager::checkConnect() if they are available.

*** Patch too long, truncated ***




More information about the kaffe mailing list
Index: kaffe/libraries/javalib/java/io/PipedInputStream.java
diff -u kaffe/libraries/javalib/java/io/PipedInputStream.java:1.15 kaffe/libraries/javalib/java/io/PipedInputStream.java:1.16
--- kaffe/libraries/javalib/java/io/PipedInputStream.java:1.15	Mon Oct  4 14:46:23 2004
+++ kaffe/libraries/javalib/java/io/PipedInputStream.java	Thu Nov 25 03:44:53 2004
@@ -151,14 +151,14 @@
   * This method receives a byte of input from the source PipedOutputStream.
   * If the internal circular buffer is full, this method blocks.
   *
   * @param byte_received The byte to write to this stream
   *
   * @exception IOException if error occurs
   * @specnote Weird. This method must be some sort of accident.
   */
-  protected synchronized void receive(int b) throws IOException
+  protected synchronized void receive(int val) throws IOException
   {
-    read_buf[0] = (byte) (b & 0xff);
+    read_buf[0] = (byte) (val & 0xff);
     receive (read_buf, 0, 1);
   }
 
@@ -237,11 +237,7 @@
     * because the end of the stream was reached.  If the stream is already
     * closed, a -1 will again be returned to indicate the end of the stream.
     * <p>
-    * This method will block if no bytes are available to be read.
-    *
-    * @param buf The buffer into which bytes will be stored
-    * @param offset The index into the buffer at which to start writing.
-    * @param len The maximum number of bytes to read.
+    * This method will block if no byte is available to be read.
     */
   public int read() throws IOException
   {
@@ -252,11 +248,7 @@
     // if this method is never called.
 
     int r = read(read_buf, 0, 1);
-
-    if (r == -1)
-      return -1;
-    else
-      return read_buf[0];
+    return r != -1 ? read_buf[0] : -1;
   }
   
   /**
@@ -151,14 +151,14 @@
   * If the internal circular buffer is full, this method blocks.
   *
-  * @param byte_received The byte to write to this stream
+  * @param val The byte to write to this stream
   *
   * @exception IOException if error occurs
Index: kaffe/libraries/javalib/java/io/PipedOutputStream.java
diff -u kaffe/libraries/javalib/java/io/PipedOutputStream.java:1.6 kaffe/libraries/javalib/java/io/PipedOutputStream.java:1.7
--- kaffe/libraries/javalib/java/io/PipedOutputStream.java:1.6	Sat Aug 30 14:18:31 2003
+++ kaffe/libraries/javalib/java/io/PipedOutputStream.java	Thu Nov 25 03:44:54 2004
@@ -129,21 +129,21 @@
     * <code>PipedInputStream</code> to which this object is connected has
     * a buffer that cannot hold all of the bytes to be written.
     *
     * @param buf The array containing bytes to write to the stream.
     * @param offset The index into the array to start writing bytes from.
     * @param len The number of bytes to write.
     *
     * @exception IOException If the stream has not been connected or has
     *                        been closed.
     */
-  public void write(byte[] b, int off, int len) throws IOException
+  public void write(byte[] buffer, int offset, int len) throws IOException
   {
     if (sink == null)
       throw new IOException ("Not connected");
     if (closed)
       throw new IOException ("Pipe closed");
       
-    sink.receive (b, off, len);
+    sink.receive(buffer, offset, len);
   }
 
   /**
@@ -129,21 +129,21 @@
     * a buffer that cannot hold all of the bytes to be written.
     *
-    * @param buf The array containing bytes to write to the stream.
+    * @param buffer The array containing bytes to write to the stream.
     * @param offset The index into the array to start writing bytes from.
     * @param len The number of bytes to write.
Index: kaffe/libraries/javalib/java/io/PipedWriter.java
diff -u kaffe/libraries/javalib/java/io/PipedWriter.java:1.4 kaffe/libraries/javalib/java/io/PipedWriter.java:1.5
--- kaffe/libraries/javalib/java/io/PipedWriter.java:1.4	Sat Aug 30 14:18:31 2003
+++ kaffe/libraries/javalib/java/io/PipedWriter.java	Thu Nov 25 03:44:54 2004
@@ -128,21 +128,21 @@
     * <code>PipedReader</code> to which this object is connected has
     * a buffer that cannot hold all of the chars to be written.
     *
     * @param buf The array containing chars to write to the stream.
     * @param offset The index into the array to start writing chars from.
     * @param len The number of chars to write.
     *
     * @exception IOException If the stream has not been connected or has
     *                        been closed.
     */
-  public void write(char[] b, int off, int len) throws IOException
+  public void write(char[] buffer, int offset, int len) throws IOException
   {
     if (sink == null)
       throw new IOException ("Not connected");
     if (closed)
       throw new IOException ("Pipe closed");
       
-    sink.receive (b, off, len);
+    sink.receive(buffer, offset, len);
   }
 
   /**
@@ -128,21 +128,21 @@
     * a buffer that cannot hold all of the chars to be written.
     *
-    * @param buf The array containing chars to write to the stream.
+    * @param buffer The array containing chars to write to the stream.
     * @param offset The index into the array to start writing chars from.
     * @param len The number of chars to write.
Index: kaffe/libraries/javalib/java/io/RandomAccessFile.java
diff -u kaffe/libraries/javalib/java/io/RandomAccessFile.java:1.27 kaffe/libraries/javalib/java/io/RandomAccessFile.java:1.28
--- kaffe/libraries/javalib/java/io/RandomAccessFile.java:1.27	Mon Oct  4 14:46:23 2004
+++ kaffe/libraries/javalib/java/io/RandomAccessFile.java	Thu Nov 25 03:44:54 2004
@@ -205,7 +205,7 @@
    * <p>
    * The file must be open for write access for this operation to succeed.
    *
-   * @param newlen The new length of the file
+   * @param newLen The new length of the file
    *
    * @exception IOException If an error occurs
    */
@@ -256,7 +256,7 @@
    * bytes are stored starting at the beginning of the array and up to 
    * <code>buf.length</code> bytes can be read.
    *
-   * @param buf The buffer to read bytes from the file into
+   * @param buffer The buffer to read bytes from the file into
    *
    * @return The actual number of bytes read or -1 if end of file
    *
@@ -271,7 +271,7 @@
    * This methods reads up to <code>len</code> bytes from the file into the
    * specified array starting at position <code>offset</code> into the array.
    *
-   * @param buf The array to read the bytes into
+   * @param buffer The array to read the bytes into
    * @param offset The index into the array to start storing bytes
    * @param len The requested number of bytes to read
    *
@@ -414,7 +414,7 @@
    * throws an exception if there is not enough data left in the stream to
    * fill the buffer
    *
-   * @param buf The buffer into which to read the data
+   * @param buffer The buffer into which to read the data
    *
    * @exception EOFException If end of file is reached before filling the 
    * buffer
@@ -434,9 +434,9 @@
    * available and throws an exception if there is not enough data left in 
    * the stream to read <code>len</code> bytes.
    *
-   * @param buf The buffer into which to read the data
+   * @param buffer The buffer into which to read the data
    * @param offset The offset into the buffer to start storing data
-   * @param len The number of bytes to read into the buffer
+   * @param count The number of bytes to read into the buffer
    *
    * @exception EOFException If end of file is reached before filling 
    * the buffer
@@ -460,8 +460,8 @@
    * four bytes read from the stream, they will be
    * transformed to an <code>int</code> in the following manner:
    * <p>
-   * <code>(int)(((byte1 & 0xFF) << 24) + ((byte2 & 0xFF) << 16) + 
-   * ((byte3 & 0xFF) << 8) + (byte4 & 0xFF)))</code>
+   * <code>(int)(((byte1 &amp; 0xFF) &lt;&lt; 24) + ((byte2 &amp; 0xFF) &lt;&lt; 16) + 
+   * ((byte3 &amp; 0xFF) &lt;&lt; 8) + (byte4 &amp; 0xFF)))</code>
    * <p>
    * The value returned is in the range of 0 to 65535.
    * <p>
@@ -524,10 +524,10 @@
    * transformed to an <code>long</code> in the following manner:
    * <p>
    * <code>
-   * (long)((((long)byte1 & 0xFF) << 56) + (((long)byte2 & 0xFF) << 48) + 
-   * (((long)byte3 & 0xFF) << 40) + (((long)byte4 & 0xFF) << 32) + 
-   * (((long)byte5 & 0xFF) << 24) + (((long)byte6 & 0xFF) << 16) + 
-   * (((long)byte7 & 0xFF) << 8) + ((long)byte9 & 0xFF)))</code>
+   * (long)((((long)byte1 &amp; 0xFF) &lt;&lt; 56) + (((long)byte2 &amp; 0xFF) &lt;&lt; 48) + 
+   * (((long)byte3 &amp; 0xFF) &lt;&lt; 40) + (((long)byte4 &amp; 0xFF) &lt;&lt; 32) + 
+   * (((long)byte5 &amp; 0xFF) &lt;&lt; 24) + (((long)byte6 &amp; 0xFF) &lt;&lt; 16) + 
+   * (((long)byte7 &amp; 0xFF) &lt;&lt; 8) + ((long)byte9 &amp; 0xFF)))</code>
    * <p>
    * The value returned is in the range of 0 to 65535.
    * <p>
@@ -612,7 +612,7 @@
    * and second byte read from the stream respectively, they will be
    * transformed to an <code>int</code> in the following manner:
    * <p>
-   * <code>(int)(((byte1 & 0xFF) << 8) + (byte2 & 0xFF))</code>
+   * <code>(int)(((byte1 &amp; 0xFF) &lt;&lt; 8) + (byte2 &amp; 0xFF))</code>
    * <p>
    * The value returned is in the range of 0 to 65535.
    * <p>
@@ -756,7 +756,7 @@
    * This method writes a single byte of data to the file. The file must
    * be open for read-write in order for this operation to succeed.
    *
-   * @param The byte of data to write, passed as an int.
+   * @param oneByte The byte of data to write, passed as an int.
    *
    * @exception IOException If an error occurs
    */
@@ -769,7 +769,7 @@
    * This method writes all the bytes in the specified array to the file.
    * The file must be open read-write in order for this operation to succeed.
    *
-   * @param buf The array of bytes to write to the file
+   * @param buffer The array of bytes to write to the file
    */
   public void write (byte[] buffer) throws IOException
   {
@@ -780,7 +780,7 @@
    * This method writes <code>len</code> bytes to the file from the specified
    * array starting at index <code>offset</code> into the array.
    *
-   * @param buf The array of bytes to write to the file
+   * @param buffer The array of bytes to write to the file
    * @param offset The index into the array to start writing file
    * @param len The number of bytes to write
    *
@@ -796,7 +796,7 @@
    * stream. For a value of <code>true</code>, 1 is written to the stream.
    * For a value of <code>false</code>, 0 is written.
    *
    * @param b The <code>boolean</code> value to write to the stream
    *
    * @exception IOException If an error occurs
    */
@@ -809,68 +809,68 @@
    * This method writes a Java <code>byte</code> value to the underlying
    * output stream.
    *
    * @param b The <code>byte</code> to write to the stream, passed 
    * as an <code>int</code>.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeByte (int v) throws IOException
+  public final void writeByte (int val) throws IOException
   {
-    out.writeByte(v);
+    out.writeByte(val);
   }
 
   /**
    * This method writes a Java <code>short</code> to the stream, high byte
    * first.  This method requires two bytes to encode the value.
    *
    * @param s The <code>short</code> value to write to the stream, 
    * passed as an <code>int</code>.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeShort (int v) throws IOException
+  public final void writeShort (int val) throws IOException
   {
-    out.writeShort(v);
+    out.writeShort(val);
   }
 
   /**
    * This method writes a single <code>char</code> value to the stream,
    * high byte first.
    *
    * @param v The <code>char</code> value to write, passed as 
    * an <code>int</code>.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeChar (int v) throws IOException
+  public final void writeChar (int val) throws IOException
   {
-    out.writeChar(v);
+    out.writeChar(val);
   }
 
   /**
    * This method writes a Java <code>int</code> to the stream, high bytes
    * first.  This method requires four bytes to encode the value.
    *
    * @param v The <code>int</code> value to write to the stream.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeInt (int v) throws IOException
+  public final void writeInt (int val) throws IOException
   {
-    out.writeInt(v);
+    out.writeInt(val);
   }
 
   /**
    * This method writes a Java <code>long</code> to the stream, high bytes
    * first.  This method requires eight bytes to encode the value.
    *
    * @param v The <code>long</code> value to write to the stream.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeLong (long v) throws IOException
+  public final void writeLong (long val) throws IOException
   {
-    out.writeLong(v);
+    out.writeLong(val);
   }
 
   /**
@@ -881,15 +881,15 @@
    * then writing this <code>int</code> value to the stream exactly the same
    * as the <code>writeInt()</code> method does.
    *
    * @param v The floating point number to write to the stream.
    *
    * @exception IOException If an error occurs
    *
    * @see #writeInt(int)
    */
-  public final void writeFloat (float v) throws IOException
+  public final void writeFloat (float val) throws IOException
   {
-    out.writeFloat(v);
+    out.writeFloat(val);
   }
 
   /**
@@ -900,16 +900,16 @@
    * then writing this <code>long</code> value to the stream exactly the same
    * as the <code>writeLong()</code> method does.
    *
    * @param v The double precision floating point number to write to the 
    * stream.
    *
    * @exception IOException If an error occurs
    *
    * @see #writeLong(long)
    */
-  public final void writeDouble (double v) throws IOException
+  public final void writeDouble (double val) throws IOException
   {
-    out.writeDouble(v);
+    out.writeDouble(val);
   }
 
   /**
@@ -917,13 +917,13 @@
    * stream.  One byte is written for each character in the <code>String</code>.
    * The high eight bits of each character are discarded.
    *
    * @param s The <code>String</code> to write to the stream
    *
    * @exception IOException If an error occurs
    */
-  public final void writeBytes (String s) throws IOException
+  public final void writeBytes (String val) throws IOException
   {
-    out.writeBytes(s);
+    out.writeBytes(val);
   }
   
   /**
@@ -931,13 +931,13 @@
    * stream.  There will be two bytes for each character value.  The high
    * byte of the character will be written first.
    *
    * @param s The <code>String</code> to write to the stream.
    *
    * @exception IOException If an error occurs
    */
-  public final void writeChars (String s) throws IOException
+  public final void writeChars (String val) throws IOException
   {
-    out.writeChars(s);
+    out.writeChars(val);
   }
   
   /**
@@ -965,13 +965,13 @@
    * character value are stored in bits 0-5 of byte three, with the high bits
    * of that byte set to "10".
    *
    * @param s The <code>String</code> to write to the output in UTF format
    *
    * @exception IOException If an error occurs
    */
-  public final void writeUTF (String s) throws IOException
+  public final void writeUTF (String val) throws IOException
   {
-    out.writeUTF(s);
+    out.writeUTF(val);
   }
   
   /**
@@ -984,6 +984,4 @@
   {
     return ch;
   }
-
-} // class RandomAccessFile
-
+}
@@ -796,7 +796,7 @@
    * For a value of <code>false</code>, 0 is written.
    *
-   * @param b The <code>boolean</code> value to write to the stream
+   * @param val The <code>boolean</code> value to write to the stream
    *
    * @exception IOException If an error occurs
@@ -809,68 +809,68 @@
    * output stream.
    *
-   * @param b The <code>byte</code> to write to the stream, passed 
+   * @param val The <code>byte</code> to write to the stream, passed 
    * as an <code>int</code>.
    *
@@ -809,68 +809,68 @@
    * first.  This method requires two bytes to encode the value.
    *
-   * @param s The <code>short</code> value to write to the stream, 
+   * @param val The <code>short</code> value to write to the stream, 
    * passed as an <code>int</code>.
    *
@@ -809,68 +809,68 @@
    * high byte first.
    *
-   * @param v The <code>char</code> value to write, passed as 
+   * @param val The <code>char</code> value to write, passed as 
    * an <code>int</code>.
    *
@@ -809,68 +809,68 @@
    * first.  This method requires four bytes to encode the value.
    *
-   * @param v The <code>int</code> value to write to the stream.
+   * @param val The <code>int</code> value to write to the stream.
    *
    * @exception IOException If an error occurs
@@ -809,68 +809,68 @@
    * first.  This method requires eight bytes to encode the value.
    *
-   * @param v The <code>long</code> value to write to the stream.
+   * @param val The <code>long</code> value to write to the stream.
    *
    * @exception IOException If an error occurs
@@ -881,15 +881,15 @@
    * as the <code>writeInt()</code> method does.
    *
-   * @param v The floating point number to write to the stream.
+   * @param val The floating point number to write to the stream.
    *
    * @exception IOException If an error occurs
@@ -900,16 +900,16 @@
    * as the <code>writeLong()</code> method does.
    *
-   * @param v The double precision floating point number to write to the 
+   * @param val The double precision floating point number to write to the 
    * stream.
    *
@@ -917,13 +917,13 @@
    * The high eight bits of each character are discarded.
    *
-   * @param s The <code>String</code> to write to the stream
+   * @param val The <code>String</code> to write to the stream
    *
    * @exception IOException If an error occurs
@@ -931,13 +931,13 @@
    * byte of the character will be written first.
    *
-   * @param s The <code>String</code> to write to the stream.
+   * @param val The <code>String</code> to write to the stream.
    *
    * @exception IOException If an error occurs
@@ -965,13 +965,13 @@
    * of that byte set to "10".
    *
-   * @param s The <code>String</code> to write to the output in UTF format
+   * @param val The <code>String</code> to write to the output in UTF format
    *
    * @exception IOException If an error occurs